pub struct Modifiers {
pub control: bool,
pub alt: bool,
pub operating_system: bool,
pub shift: bool,
}Expand description
The state of keyboard modifier keys.
Fields
control: boolIf true, a control key is currently depressed.
alt: boolIf true, an alt key is currently depressed.
operating_system: boolIf true, an “Operating System key” is currently depressed. For most keyboards, this is the Windows key or the Command/Apple key.
shift: boolIf true, a shift key is currently depressed.
Implementations
Sourceimpl Modifiers
impl Modifiers
Sourcepub const fn primary_modifier(&self) -> bool
pub const fn primary_modifier(&self) -> bool
Returns true if the primary modifier of the current OS is depressed. For
Mac and iOS, this returns operating_system. For all other OSes, this
returns control.
Sourcepub const fn command_key(&self) -> bool
pub const fn command_key(&self) -> bool
Returns true if the command key/Apple key is pressed. This only returns
true if operating_system key is true and the current operating system
is Mac or iOS.